@@ -28,14 +28,14 @@ def arg_parser():
     )
 
     parser.add_argument('-c', '--check', action='store_true', help='ensure all prerequisites are met')
-    parser.add_argument('-u', '--upload', action='store_true', help='upload software: robin-sd-upload --upload --type=radar_type --number=version_number --path=upload_folder_path')
+    parser.add_argument('-u', '--upload', action='store_true', help='upload software: robin-sd-upload --upload --type=radar_type --number=version_number --path=upload_folder_absolute_path')
     parser.add_argument('-v', '--version', action='version', version='%(prog)s {version}'.format(version=_version.__version__))
     parser.add_argument('-s', '--slack', action='store_true', help='Send the logs to IT/DevOps Slack channel')
 
     # arguments for upload
-    parser.add_argument('-t', "--type", type=str, help="radar type")
-    parser.add_argument('-n', "--number", type=str, help="version number of the software")
-    parser.add_argument('-p', "--path", type=str, help="upload file absolute path")
+    parser.add_argument('-t', "--type", help="radar type")
+    parser.add_argument('-n', "--number", help="version number of the software")
+    parser.add_argument('-p', "--path", help="upload file absolute path")
 
     args = parser.parse_args()
     config = yaml_parser.parse_config()
